<?php

namespace FiloBlu\CegidY2\Api\SaleDocumentService\EnumType;

/**
 * This class stands for ShippingStatus EnumType
 * Meta information extracted from the WSDL
 * - documentation: e-Commerce shipment status
 * - nillable: true
 * - type: tns:ShippingStatus
 * @subpackage Enumerations
 */
class ShippingStatus
{
    /**
     * Constant for value 'Pending'
     * Meta information extracted from the WSDL
     * - documentation: Not sent.
     * @return string 'Pending'
     */
    const VALUE_PENDING = 'Pending';
    /**
     * Constant for value 'Totally'
     * Meta information extracted from the WSDL
     * - documentation: Sent.
     * @return string 'Totally'
     */
    const VALUE_TOTALLY = 'Totally';
    /**
     * Constant for value 'Partially'
     * Meta information extracted from the WSDL
     * - documentation: Sent partially.
     * @return string 'Partially'
     */
    const VALUE_PARTIALLY = 'Partially';
    /**
     * Constant for value 'InProgress'
     * Meta information extracted from the WSDL
     * - documentation: Shipment in progress.
     * @return string 'InProgress'
     */
    const VALUE_IN_PROGRESS = 'InProgress';
    /**
     * Return true if value is allowed
     * @uses self::getValidValues()
     * @param mixed $value value
     * @return bool true|false
     */
    public static function valueIsValid($value)
    {
        return ($value === null) || in_array($value, self::getValidValues(), true);
    }
    /**
     * Return allowed values
     * @uses self::VALUE_PENDING
     * @uses self::VALUE_TOTALLY
     * @uses self::VALUE_PARTIALLY
     * @uses self::VALUE_IN_PROGRESS
     * @return string[]
     */
    public static function getValidValues()
    {
        return array(
            self::VALUE_PENDING,
            self::VALUE_TOTALLY,
            self::VALUE_PARTIALLY,
            self::VALUE_IN_PROGRESS,
        );
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
